@@ -7,7 +7,7 @@ from oaklib.implementations import UbergraphImplementation
 from functools import lru_cache, reduce
 
 from typing import List, Union, TextIO, Optional, Dict
-from linkml_runtime.utils.schemaview import SchemaView
+from linkml_runtime.utils.schemaview import SchemaView, Namespaces
 from linkml_runtime.linkml_model.meta import (
     SchemaDefinition,
     Element,
@@ -17,15 +17,14 @@ from linkml_runtime.linkml_model.meta import (
     SlotDefinition,
 )
 from pprint import pprint
-
 from bmt.utils import format_element, parse_name
 
 Url = str
 Path = str
 
-REMOTE_PATH = "https://raw.githubusercontent.com/biolink/biolink-model/v3.2.1/biolink-model.yaml"
-PREDICATE_MAP = 'https://raw.githubusercontent.com/biolink/biolink-model/v3.2.1/predicate_mapping.yaml'
-INFORES_MAP = 'https://raw.githubusercontent.com/biolink/biolink-model/v3.2.1/infores_catalog_nodes.tsv'
+REMOTE_PATH = "https://raw.githubusercontent.com/biolink/biolink-model/v3.2.2/biolink-model.yaml"
+PREDICATE_MAP = 'https://raw.githubusercontent.com/biolink/biolink-model/v3.2.2/predicate_mapping.yaml'
+INFORES_MAP = 'https://raw.githubusercontent.com/biolink/biolink-model/v3.2.2/infores_catalog_nodes.tsv'
 
 NODE_PROPERTY = "node property"
 ASSOCIATION_SLOT = "association slot"
@@ -593,6 +592,11 @@ class Toolkit(object):
             for e, el in self.view.all_elements().items():
                 if el.name.lower() == name.lower():
                     element = el
+
+        if type(element) == ClassDefinition and element.class_uri is None:
+            element.class_uri = format_element(element)
+        if type(element) == SlotDefinition and element.slot_uri is None:
+            element.slot_uri = format_element(element)
         return element
 
     def get_slot_domain(
@@ -1326,7 +1330,6 @@ class Toolkit(object):
     ) -> List[str]:
         """
         Get a Biolink Model element by prefix.
-        This method return the common ancestor of the set of elements referenced by uriorcurie.
 
         Parameters
         ----------
@@ -1431,9 +1434,7 @@ class Toolkit(object):
             A list of Biolink elements that correspond to the given identifier IRI/CURIE
 
         """
-        mappings = self.view.get_mappings().get(
-            self.view.namespaces.uri_for(identifier), set()
-        )
+        mappings = set(self.view.get_element_by_mapping(identifier))
         if not mappings:
             exact = set(self.get_element_by_exact_mapping(identifier))
             mappings.update(exact)
@@ -1472,11 +1473,17 @@ class Toolkit(object):
             A list of Biolink elements that correspond to the given identifier IRI/CURIE
 
         """
-        mappings = self.view.exact_mappings.get(
-            self.view.namespaces.uri_for(identifier), set()
-        )
-        logger.debug(mappings)
-        return self._format_all_elements(mappings, formatted)
+        mapping_index = self.view.get_mapping_index()
+        elements = self.view.get_element_by_mapping(identifier)
+        if elements:
+            for element in elements:
+                if mapping_index.get(identifier)[0] == 'exact' and mapping_index.get(identifier)[1] == element:
+                    formatted_element = format_element(element)
+                    return [formatted_element]
+                else:
+                    return []
+        else:
+            return []
 
     @lru_cache(CACHE_SIZE)
     def get_element_by_close_mapping(
@@ -1499,10 +1506,17 @@ class Toolkit(object):
             A list of Biolink elements that correspond to the given identifier IRI/CURIE
 
         """
-        mappings = self.view.close_mappings.get(
-            self.view.namespaces.uri_for(identifier), set()
-        )
-        return self._format_all_elements(mappings, formatted)
+        mapping_index = self.view.get_mapping_index()
+        elements = self.view.get_element_by_mapping(identifier)
+        if elements:
+            for element in elements:
+                if mapping_index.get(identifier)[0] == 'close' and mapping_index.get(identifier)[1] == element:
+                    formatted_element = format_element(element)
+                    return [formatted_element]
+                else:
+                    return []
+        else:
+            return []
 
     @lru_cache(CACHE_SIZE)
     def get_element_by_related_mapping(
@@ -1525,11 +1539,17 @@ class Toolkit(object):
             A list of Biolink elements that correspond to the given identifier IRI/CURIE
 
         """
-        mappings = self.view.related_mappings.get(
-            self.view.namespaces.uri_for(identifier), set()
-        )
-        return self._format_all_elements(mappings, formatted)
-
+        mapping_index = self.view.get_mapping_index()
+        elements = self.view.get_element_by_mapping(identifier)
+        if elements:
+            for element in elements:
+                if mapping_index.get(identifier)[0] == 'related' and mapping_index.get(identifier)[1] == element:
+                    formatted_element = format_element(element)
+                    return [formatted_element]
+                else:
+                    return []
+        else:
+            return []
     @lru_cache(CACHE_SIZE)
     def get_element_by_narrow_mapping(
             self, identifier: str, formatted: bool = False
@@ -1551,10 +1571,17 @@ class Toolkit(object):
             A list of Biolink elements that correspond to the given identifier IRI/CURIE
 
         """
-        mappings = self.view.narrow_mappings.get(
-            self.view.namespaces.uri_for(identifier), set()
-        )
-        return self._format_all_elements(mappings, formatted)
+        mapping_index = self.view.get_mapping_index()
+        elements = self.view.get_element_by_mapping(identifier)
+        if elements:
+            for element in elements:
+                if mapping_index.get(identifier)[0] == 'narrow' and mapping_index.get(identifier)[1] == element:
+                    formatted_element = format_element(element)
+                    return [formatted_element]
+                else:
+                    return []
+        else:
+            return []
 
     @lru_cache(CACHE_SIZE)
     def get_element_by_broad_mapping(
@@ -1577,10 +1604,17 @@ class Toolkit(object):
             A list of Biolink elements that correspond to the given identifier IRI/CURIE
 
         """
-        mappings = self.view.broad_mappings.get(
-            self.view.namespaces.uri_for(identifier), set()
-        )
-        return self._format_all_elements(mappings, formatted)
+        mapping_index = self.view.get_mapping_index()
+        elements = self.view.get_element_by_mapping(identifier)
+        if elements:
+            for element in elements:
+                if mapping_index.get(identifier)[0] == 'broad' and mapping_index.get(identifier)[1] == element:
+                    formatted_element = format_element(element)
+                    return [formatted_element]
+                else:
+                    return []
+        else:
+            return []
 
     @lru_cache(CACHE_SIZE)
     def get_all_elements_by_mapping(
